## OpenAGS: An open source analysis tool for PGAA and NAA
Note: This readme is still very much a work in progress.

### Running
- pip install -r requirements.txt, and then python3 server.py in the webserver directory
- This will run a webserver on 127.0.0.1:8000

### Code breakdown
- The backend, which does all the calculations, is in /backend.
- The web server is in /webserver/server.py
- Static webpages are in /webserver
- Jinja Templates are in /webserver/templates
- JS is in /webserver/static/js
